<?php

/**
 * This is the model class for table "artikel".
 *
 * The followings are the available columns in table 'artikel':
 * @property string $ImportID
 * @property string $Name
 * @property double $Preis
 * @property string $RefWarengruppeID
 * @property string $Groesse
 * @property string $Marke
 * @property string $HappyHourFlag
 * @property string $RefUserID
 * @property string $ErfassungTS
 */
class Artikel extends CActiveRecord
{
	/**
	 * @return string the associated database table name
	 */
	public function tableName()
	{
		return 'artikel';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		// NOTE: you should only define rules for those attributes that
		// will receive user inputs.
		return array(
			array('ImportID','unique'),
            array('Name, Preis, RefUserID, HappyHourFlag', 'required'),
			//array('Preis', 'numerical'),
			array('Name', 'length', 'max'=>100),
			array('RefWarengruppeID, RefUserID', 'length', 'max'=>20),
			array('Groesse', 'length', 'max'=>10),
			array('Marke', 'length', 'max'=>50),
            array('ErfassungTS', 'safe'),
			array('HappyHourFlag', 'length', 'max'=>5),
            array('HappyHourFlag','in','range'=>array('Ja','Nein'),'allowEmpty'=>false, 'message'=>'Es sind nur die Werte Ja oder Nein erlaubt'),
            //sondervalidierungen:
            array('Groesse', 'validateGroesse','message'=>'Länge/Größe ungültig, Format XXS-XXL oder Nummer 0-999,9'),
            array('Preis', 'validatePreis','message'=>'Preiseingabe ungültig, Format 12345,12 verwenden, Max=99999 Min=0,01'),
			// The following rule is used by search().
			array('ImportID, Name, Preis, RefWarengruppeID, Groesse, Marke, HappyHourFlag, RefUserID, ErfassungTS', 'safe', 'on'=>'search'),
		);
	}

	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		// NOTE: you may need to adjust the relation name and the related
		// class name for the relations automatically generated below.
		return array(
            //'warengruppe'=>array(self::HAS_ONE,'RefWarengruppeID','ID'),
            //'User'=>array(self::BELONGS_TO, 'User', 'RefUserID'),
            //'Warengruppe'=>array(self::BELONGS_TO, 'Warengruppe', 'ID'),
		);
	}

	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
			'ImportID' => 'ID',
			'Name' => 'Name',
			'Preis' => 'Preis',
			'RefWarengruppeID' => 'Warengruppe',
			'Groesse' => 'Größe/Länge',
			'Marke' => 'Marke',
			'HappyHourFlag' => 'Happy Hour',
			'RefUserID' => 'Ref User',
            'ErfassungTS' => 'Erfassungszeit',
		);
	}

	/**
	 * Retrieves a list of models based on the current search/filter conditions.
	 *
	 * Typical usecase:
	 * - Initialize the model fields with values from filter form.
	 * - Execute this method to get CActiveDataProvider instance which will filter
	 * models according to data in model fields.
	 * - Pass data provider to CGridView, CListView or any similar widget.
	 *
	 * @return CActiveDataProvider the data provider that can return the models
	 * based on the search/filter conditions.
	 */
	public function search()
	{

        //ermittle user id, wenn keine user id dann liefere keine daten zurück
        $user_id=Yii::app()->user->id;
        if($user_id==null)
            return null;    
        
		$criteria=new CDbCriteria;

		$criteria->compare('ImportID',$this->ImportID,false); //nur exakt
		$criteria->compare('Name',$this->Name,true);
		$criteria->compare('Preis',$this->Preis);
		$criteria->compare('RefWarengruppeID',$this->RefWarengruppeID,true);
		$criteria->compare('Groesse',$this->Groesse,true);
		$criteria->compare('Marke',$this->Marke,true);
		$criteria->compare('HappyHourFlag',$this->HappyHourFlag,true);
        $criteria->compare('ErfassungTS',$this->ErfassungTS,true);
        
        $criteria->compare('RefUserID',$user_id,false); //limitation der daten immer exakt auf die user_id, d.h. jeder user kann nur seine daten sehen

		return new CActiveDataProvider($this, array(
			'criteria'=>$criteria,
            'pagination'=>array('pageSize'=>1000,), //1000 artikel pro seite
            'sort'=>array(
                'defaultOrder'=>'ErfassungTS DESC'),
		));
	}

	/**
	 * Returns the static model of the specified AR class.
	 * Please note that you should have this exact method in all your CActiveRecord descendants!
	 * @param string $className active record class name.
	 * @return Artikel the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}
    
    /**
    * Eigene Validierungsroutine um Preise zu validieren gültig Format 12345,12 oder 12345.11 verwenden, Max=99999 Min=0,01
    * 
    * @param mixed $attribute
    * @param mixed $params
    */
    public function validatePreis($attribute,$params)
    {
        //info von http://stackoverflow.com/questions/15516172/how-to-add-rules-using-yii-framework-in-model
        
        $error=null;
        $attribute_content=$this[$attribute];
        
        //ersetze komma durch punkt für validierung
        $attribute_content=str_replace(",",".",$attribute_content);
        
        //daten eine zahl
        if(!is_numeric($attribute_content))
            $error=1;
            
        //zahlk zwischen 0,01 und 99999
        if((float)$attribute_content < 0.01 || $attribute_content>99999)
            $error=1;
        
        //maximal 5 corkomma und 2 nachkommastellen    
        $split=explode(".",$attribute_content);
        if((isset($split[0]) && strlen($split[0])>5) || (isset($split[1]) && strlen($split[1])>2))
            $error=1;    
            
        if($error)
        {
            //$this->addError('duration','validation message');
            $this->addError($attribute,$params['message']);
        }
    }
    
    /**
    * Eigene Validierungsroutine um Länge/Größe zu validieren, Format XXS-XXL oder Nummer 0-999,9
    * 
    * @param mixed $attribute
    * @param mixed $params
    */
    public function validateGroesse($attribute,$params)
    {
        //info von http://stackoverflow.com/questions/15516172/how-to-add-rules-using-yii-framework-in-model
        
        $valid_array=array();
        array_push($valid_array,"XXS");
        array_push($valid_array,"XS");
        array_push($valid_array,"S");
        array_push($valid_array,"M");
        array_push($valid_array,"L");
        array_push($valid_array,"XL");
        array_push($valid_array,"XXL");
        
        $error=null;
        $attribute_content=$this[$attribute];
        
        //ersetze komma durch punkt für validierung
        $attribute_content=str_replace(",",".",$attribute_content);
        
        //daten eine zahl
        if(is_numeric($attribute_content))
        {
            //maximal 3 vorkomma und 1 nachkommastelle    
            $split=explode(".",$attribute_content);
            if((isset($split[0]) && strlen($split[0])>3) || (isset($split[1]) && strlen($split[1])>1))
                $error=1;  
                   
            //zahlk zwischen 0 und 999.9
            if((float)$attribute_content < 0 || $attribute_content>999.9)
                $error=1;      
        }
        else if($attribute_content!="") //daten sind ein string
        {
            //daten sind immer uppercase
            $attribute_content=strtoupper($attribute_content);
            //wenn daten nicht in array -> error
            if(!in_array($attribute_content,$valid_array))
                $error=1;
        }
        else if($attribute_content=="") //daten sind leer
        {
            //alles ok da optionaler wert
        }
            
            
        if($error)
        {
            //$this->addError('duration','validation message');
            $this->addError($attribute,$params['message']);
        }
    }
    
    /**
    * Manipuliert Format von bestimmten Artikeldaten vor Speicherung/Update (Preis, Größe XL/XS etc, ... )
    * @param mixed $post - HTTP Post request zu dem Modell, zb $_:Post["Artikel"]
    */
    public function manipulateArtikelData($post)
    {
        //wenn warengruppe nicht gesetzt ist, setze default warengruppe 0 damit in changelog nicht laufend einträge
        if(isset($post["RefWarengruppeID"]) && $post["RefWarengruppeID"]=="")
            $post["RefWarengruppeID"]="0";
        
        //preiseingabe wenn in komma dann mit punkt manipulieren, damit eingabe mit komma und punkt möglich
        if(isset($post["Preis"]) && $post["Preis"]!="")
            $post["Preis"]=str_replace(",",".",$post["Preis"]);
        
        //wenn größe vorhanden, ersetze komma immer durch punkt
        if(isset($post["Groesse"]) && $post["Groesse"]!="")
            $post["Groesse"]=str_replace(",",".",$post["Groesse"]);
                
        //größe XL, XS, etc daten sind immer uppercase
        if(isset($post["Groesse"]) && $post["Groesse"]!="" && !is_numeric($post["Groesse"]))
            $post["Groesse"]=strtoupper($post["Groesse"]);
            
        return $post;   
    }
}
